/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

package org.mozilla.fenix.tabstray.browser

import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.collect
import kotlinx.coroutines.flow.map
import mozilla.components.browser.state.state.TabGroup
import mozilla.components.lib.state.helpers.AbstractBinding
import mozilla.components.support.ktx.kotlinx.coroutines.flow.ifChanged
import org.mozilla.fenix.tabstray.TabsTrayState
import org.mozilla.fenix.tabstray.TabsTrayStore

/**
 * A search-term tab group observer that updates the provided [tray].
 */
class TabGroupBinding(
    store: TabsTrayStore,
    private val tray: (List<TabGroup>) -> Unit
) : AbstractBinding<TabsTrayState>(store) {
    override suspend fun onState(flow: Flow<TabsTrayState>) {
        flow.map { it.searchTermPartition?.tabGroups ?: emptyList() }
            .ifChanged()
            .collect {
                tray.invoke(it.filter { tabGroup -> tabGroup.tabIds.isNotEmpty() })
            }
    }
}
